# Get MLCommons Training Source

This [CM script](https://github.com/mlcommons/ck/blob/master/cm/docs/specs/script.md) 
git clones and installs the [MLCommons Logging library]( https://github.com/mlcommons/logging ).

## Commands

To install
```
cm run script --tags=get,mlperf,logging
```
or

```
cmr "get mlperf logging"
```
